==> errai-codegen-3.0.4.Final.jar: org/jboss/errai/codegen/StringStatement.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.codegen;

import org.jboss.errai.codegen.meta.MetaClass;
import org.jboss.errai.codegen.meta.MetaClassFactory;

public class StringStatement extends AbstractStatement {
  private final String statement;
  private final MetaClass clazz;

  public StringStatement(final String statement) {
    this(statement, null);
  }

  public StringStatement(final String statement, final MetaClass returnType) {
    this.statement = statement;
    this.clazz = returnType;
  }

  public static StringStatement of(final String statement) {
    return new StringStatement(statement);
  }

  public static StringStatement of(final String statement, final MetaClass returnType) {
    return new StringStatement(statement, returnType);
  }

  public static StringStatement of(final String statement, final Class returnType) {
    return of(statement, MetaClassFactory.get(returnType));
  }

  @Override
  public String generate(final Context context) {
    return statement;
  }

  @Override
  public MetaClass getType() {
    return clazz;
  }
}

==> errai-codegen-4.0.0.Final.jar: org/jboss/errai/codegen/StringStatement.java <==
/*
 * Copyright (C) 2011 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.codegen;

import org.jboss.errai.codegen.meta.MetaClass;
import org.jboss.errai.codegen.meta.MetaClassFactory;

public class StringStatement extends AbstractStatement {
  private final String statement;
  private final MetaClass clazz;

  public StringStatement(final String statement) {
    this(statement, null);
  }

  public StringStatement(final String statement, final MetaClass returnType) {
    this.statement = statement;
    this.clazz = returnType;
  }

  public static StringStatement of(final String statement) {
    return new StringStatement(statement);
  }

  public static StringStatement of(final String statement, final MetaClass returnType) {
    return new StringStatement(statement, returnType);
  }

  public static StringStatement of(final String statement, final Class<?> returnType) {
    return of(statement, MetaClassFactory.get(returnType));
  }

  @Override
  public String generate(final Context context) {
    return statement;
  }

  @Override
  public MetaClass getType() {
    return clazz;
  }
}
